@@ -1,3 +1,4 @@
+import copy
 import unittest2
 from ldtools.cli import get_parser
 import argparse
@@ -10,35 +11,38 @@ class ParserTestCase(unittest2.TestCase):
             follow_all=False,
             follow_uris=[],
             only_print_uris=False,
-            print_detailled_resources_limit=300,
-            url=[],
+            print_detailed_resources_limit=300,
+            origin_urls=[],
             verbosity=2,
-            sockettimeout=None,
+            socket_timeout=None,
             only_negotiate=False,
             only_print_uri_content=False,
             GRAPH_SIZE_LIMIT=None,
+            print_all_resources=False
         )
 
-    def _check_equals(self, str, result):
+    def _check_equals(self, str, expected_result):
         # cannot test this: self._check_equals("--version", {'e':1})
-        parser = get_parser()
-        self.default_arguments_dict.update(result)
-        self.assertEqual(parser.parse_args(str.split()),
-        argparse.Namespace(**self.default_arguments_dict))
+        result_dct = copy.copy(self.default_arguments_dict)
+        result_dct.update(expected_result)
+        self.assertDictEqual(
+            get_parser().parse_args(str.split()).__dict__,
+            result_dct
+        )
 
     def test_arguments_verbosity(self):
-        self._check_equals("http://a.com --verbosity 1", dict(verbosity=1,
-            url=["http://a.com"]))
+        self._check_equals("http://a.com --verbosity 1",
+            dict(verbosity=1, origin_urls=["http://a.com"]))
 
     def test_arguments_depth(self):
-        self._check_equals("http://a.com --depth 5", dict(depth=5,
-            url=["http://a.com"]))
+        self._check_equals("http://a.com --depth 5",
+            dict(depth=5, origin_urls=["http://a.com"]))
 
     def test_urls_and_follow_uris(self):
         self._check_equals("http://a.com "
             "--follow-uris http://rdfs.com/seeAlso1 "
             "--follow-uris http://rdfs.com/seeAlso2 ",
-            dict(url=["http://a.com"],
+            dict(origin_urls=["http://a.com"],
                  follow_uris=["http://rdfs.com/seeAlso1",
                               "http://rdfs.com/seeAlso2"]))
 
@@ -47,7 +51,7 @@ class ParserTestCase(unittest2.TestCase):
             "http://b.com "
             "--follow-uris http://rdfs.com/seeAlso1 "
             "--follow-uris http://rdfs.com/seeAlso2 ",
-            dict(url=["http://a.com", "http://b.com"],
+            dict(origin_urls=["http://a.com", "http://b.com"],
                  follow_uris=["http://rdfs.com/seeAlso1",
                                 "http://rdfs.com/seeAlso2"]))
 
@@ -56,6 +60,6 @@ class ParserTestCase(unittest2.TestCase):
             "--follow-uris http://rdfs.com/seeAlso2 "
             "http://a.com "
             "http://b.com ",
-            dict(url=["http://a.com", "http://b.com"],
+            dict(origin_urls=["http://a.com", "http://b.com"],
                  follow_uris=["http://rdfs.com/seeAlso1",
                                 "http://rdfs.com/seeAlso2"]))
