@@ -150,7 +150,3 @@ class ModelFilterAndSetattrTestCase(unittest2.TestCase):
         o2.another_attr = "test"
 
         self.assertEqual(len(list(Sample3.objects.filter(another_attr="test2"))), 1)
-
-
-class ManagerFilter(unittest2.TestCase):
-    pass
\ No newline at end of file
